UserID class

Constructors

UserID(String domain, String username, bool active, {bool registered = true})
const

Properties

active → bool
final
domain → String
final
hashCode → int
The hash code for this object.
no setterinherited
registered → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
username → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited