Cert class

Constructors

Cert({required String authAddress, required String authType, required String authUserName, required String domain, required bool selected})
const
Cert.fromJson(JSONMap map)
factory

Properties

authAddress → String
final
authType → String
final
authUserName → String
final
domain → String
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selected → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited