EventResult class

Constructors

EventResult({required EventType type, SiteInfo? siteInfo, ServerInfo? serverInfo, dynamic result})
EventResult.fromJson(JSONMap json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
result → dynamic
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serverInfo → ServerInfo?
final
siteInfo → SiteInfo?
final
type → EventType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited