Message class

Available extensions

Constructors

Message(String cmd, int to, dynamic result, int id)
Message.fromJson(JSONMap json)

Properties

certList → List<Cert>

Available on Message, provided by the CertListExt extension

Return: CertList
no setter
cmd ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ int
getter/setter pair
portOpened → PortOpened

Available on Message, provided by the PortOpenedExt extension

Return: True (port opened) or False (port closed).
no setter
result ↔ dynamic
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serverInfo → ServerInfo

Available on Message, provided by the ServerInfoMessage extension

no setter
siteInfo → SiteInfo

Available on Message, provided by the SiteInfoMessageExt extension

no setter
siteList → List<SiteInfo>

Available on Message, provided by the SiteListExt extension

Return: SiteList
no setter
to ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → JSONMap
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited