PromptOrError class

Constructors

PromptOrError({PromptResult? prompt, Error? error})
const

Properties

error → Error?
final
hashCode → int
The hash code for this object.
no setterinherited
isErr → bool
no setter
isPrompt → bool
no setter
prompt → PromptResult?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited