ResponseResult class

Available extensions

Constructors

ResponseResult({required int id, required ResponseType type, Message? message, PromptResult? prompt, EventResult? event, Error? error, dynamic json})
ResponseResult.fromJson(JSONMap json)
factory

Properties

error → Error?
final
event → EventResult?
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
final
isError → bool
no setter
isEvent → bool
no setter
isMessage → bool
no setter
isPrompt → bool
no setter
json → dynamic
final
message → Message?
final
prompt → PromptResult?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toMsgOrErr → MessageOrError

Available on ResponseResult, provided by the MsgOrErr extension

no setter
toMsgOrPrompt → MessageOrPrompt

Available on ResponseResult, provided by the MsgOrPrompt extension

no setter
toMsgOrPromptOrErr → MessageOrPromptOrError

Available on ResponseResult, provided by the MsgOrPromptOrErr extension

no setter
toPromptOrErr → PromptOrError

Available on ResponseResult, provided by the PromptOrErr extension

no setter
type → ResponseType
final
value → dynamic
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited