Settings class

Constructors

Settings({required int added, required List<String> permissions, required int sizeFilesOptional, required int sizeOptional, required bool serving, required Cache cache, required int optionalDownloaded, required bool own, String? ajaxKey, int? downloaded, int? size, int? sizeLimit, String? autodownloadoptional, num? modified})
Settings.fromJson(Map<String, dynamic> json)
factory

Properties

added ↔ int
getter/setter pair
ajaxKey ↔ String?
getter/setter pair
autodownloadoptional ↔ String?
getter/setter pair
cache ↔ Cache
getter/setter pair
downloaded ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
modified ↔ num?
getter/setter pair
optionalDownloaded ↔ int
getter/setter pair
own ↔ bool
getter/setter pair
permissions ↔ List<String>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serving ↔ bool
getter/setter pair
size ↔ int?
getter/setter pair
sizeFilesOptional ↔ int
getter/setter pair
sizeLimit ↔ int?
getter/setter pair
sizeOptional ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → JSONMap
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited